reintern_directives

Function reintern_directives 

pub fn reintern_directives(directives: &mut [Spanned<Directive>]) -> usize
Re-intern all strings in directives to deduplicate memory.

Walks through all directives and re-interns account names and currencies using a shared StringInterner, so identical strings share a single Arc<str> allocation. Returns the number of strings that were deduplicated (i.e., strings that were found to already exist in the interner).